pub enum MaterialProperty {
Show 20 variants
Float(f32),
FloatArray(Vec<f32>),
Int(i32),
IntArray(Vec<i32>),
UInt(u32),
UIntArray(Vec<u32>),
Vector2(Vector2<f32>),
Vector2Array(Vec<Vector2<f32>>),
Vector3(Vector3<f32>),
Vector3Array(Vec<Vector3<f32>>),
Vector4(Vector4<f32>),
Vector4Array(Vec<Vector4<f32>>),
Matrix2(Matrix2<f32>),
Matrix2Array(Vec<Matrix2<f32>>),
Matrix3(Matrix3<f32>),
Matrix3Array(Vec<Matrix3<f32>>),
Matrix4(Matrix4<f32>),
Matrix4Array(Vec<Matrix4<f32>>),
Bool(bool),
Color(Color),
}Expand description
A set of possible material property types.
Variants
Float(f32)
Real number.
FloatArray(Vec<f32>)
Real number array.
Int(i32)
Integer number.
IntArray(Vec<i32>)
Integer number array.
UInt(u32)
Natural number.
UIntArray(Vec<u32>)
Natural number array.
Vector2(Vector2<f32>)
Two-dimensional vector.
Vector2Array(Vec<Vector2<f32>>)
Two-dimensional vector array.
Vector3(Vector3<f32>)
Three-dimensional vector.
Vector3Array(Vec<Vector3<f32>>)
Three-dimensional vector array.
Vector4(Vector4<f32>)
Four-dimensional vector.
Vector4Array(Vec<Vector4<f32>>)
Four-dimensional vector array.
Matrix2(Matrix2<f32>)
2x2 Matrix.
Matrix2Array(Vec<Matrix2<f32>>)
2x2 Matrix array.
Matrix3(Matrix3<f32>)
3x3 Matrix.
Matrix3Array(Vec<Matrix3<f32>>)
3x3 Matrix array.
Matrix4(Matrix4<f32>)
4x4 Matrix.
Matrix4Array(Vec<Matrix4<f32>>)
4x4 Matrix array.
Bool(bool)
Boolean value.
Color(Color)
An sRGB color.
Implementations
Sourceimpl MaterialProperty
impl MaterialProperty
pub const FLOAT_F_0: &'static str = "Float@0"
pub const FLOAT_ARRAY_F_0: &'static str = "FloatArray@0"
pub const INT_F_0: &'static str = "Int@0"
pub const INT_ARRAY_F_0: &'static str = "IntArray@0"
pub const U_INT_F_0: &'static str = "UInt@0"
pub const U_INT_ARRAY_F_0: &'static str = "UIntArray@0"
pub const VECTOR_2_F_0: &'static str = "Vector2@0"
pub const VECTOR_2_ARRAY_F_0: &'static str = "Vector2Array@0"
pub const VECTOR_3_F_0: &'static str = "Vector3@0"
pub const VECTOR_3_ARRAY_F_0: &'static str = "Vector3Array@0"
pub const VECTOR_4_F_0: &'static str = "Vector4@0"
pub const VECTOR_4_ARRAY_F_0: &'static str = "Vector4Array@0"
pub const MATRIX_2_F_0: &'static str = "Matrix2@0"
pub const MATRIX_2_ARRAY_F_0: &'static str = "Matrix2Array@0"
pub const MATRIX_3_F_0: &'static str = "Matrix3@0"
pub const MATRIX_3_ARRAY_F_0: &'static str = "Matrix3Array@0"
pub const MATRIX_4_F_0: &'static str = "Matrix4@0"
pub const MATRIX_4_ARRAY_F_0: &'static str = "Matrix4Array@0"
pub const BOOL_F_0: &'static str = "Bool@0"
pub const COLOR_F_0: &'static str = "Color@0"
Sourceimpl MaterialProperty
impl MaterialProperty
Sourcepub fn as_ref(&self) -> MaterialPropertyRef<'_>
pub fn as_ref(&self) -> MaterialPropertyRef<'_>
Maps the inner value of the property to its respective reference.
Sourceimpl MaterialProperty
impl MaterialProperty
Sourcepub fn as_float_array(&self) -> Option<&[f32]>
pub fn as_float_array(&self) -> Option<&[f32]>
Tries to unwrap property value as float array.
Sourcepub fn as_int_array(&self) -> Option<&[i32]>
pub fn as_int_array(&self) -> Option<&[i32]>
Tries to unwrap property value as integer array.
Sourcepub fn as_uint_array(&self) -> Option<&[u32]>
pub fn as_uint_array(&self) -> Option<&[u32]>
Tries to unwrap property value as unsigned integer array.
Sourcepub fn as_vector2(&self) -> Option<Vector2<f32>>
pub fn as_vector2(&self) -> Option<Vector2<f32>>
Tries to unwrap property value as two-dimensional vector.
Sourcepub fn as_vector2_array(&self) -> Option<&[Vector2<f32>]>
pub fn as_vector2_array(&self) -> Option<&[Vector2<f32>]>
Tries to unwrap property value as two-dimensional vector array.
Sourcepub fn as_vector3(&self) -> Option<Vector3<f32>>
pub fn as_vector3(&self) -> Option<Vector3<f32>>
Tries to unwrap property value as three-dimensional vector.
Sourcepub fn as_vector3_array(&self) -> Option<&[Vector3<f32>]>
pub fn as_vector3_array(&self) -> Option<&[Vector3<f32>]>
Tries to unwrap property value as three-dimensional vector array.
Sourcepub fn as_vector4(&self) -> Option<Vector4<f32>>
pub fn as_vector4(&self) -> Option<Vector4<f32>>
Tries to unwrap property value as four-dimensional vector.
Sourcepub fn as_vector4_array(&self) -> Option<&[Vector4<f32>]>
pub fn as_vector4_array(&self) -> Option<&[Vector4<f32>]>
Tries to unwrap property value as four-dimensional vector array.
Sourcepub fn as_matrix2(&self) -> Option<Matrix2<f32>>
pub fn as_matrix2(&self) -> Option<Matrix2<f32>>
Tries to unwrap property value as 2x2 matrix.
Sourcepub fn as_matrix2_array(&self) -> Option<&[Matrix2<f32>]>
pub fn as_matrix2_array(&self) -> Option<&[Matrix2<f32>]>
Tries to unwrap property value as 2x2 matrix array.
Sourcepub fn as_matrix3(&self) -> Option<Matrix3<f32>>
pub fn as_matrix3(&self) -> Option<Matrix3<f32>>
Tries to unwrap property value as 3x3 matrix.
Sourcepub fn as_matrix3_array(&self) -> Option<&[Matrix3<f32>]>
pub fn as_matrix3_array(&self) -> Option<&[Matrix3<f32>]>
Tries to unwrap property value as 3x3 matrix array.
Sourcepub fn as_matrix4(&self) -> Option<Matrix4<f32>>
pub fn as_matrix4(&self) -> Option<Matrix4<f32>>
Tries to unwrap property value as 4x4 matrix.
Sourcepub fn as_matrix4_array(&self) -> Option<&[Matrix4<f32>]>
pub fn as_matrix4_array(&self) -> Option<&[Matrix4<f32>]>
Tries to unwrap property value as 4x4 matrix array.