pub enum MaterialResourceBinding {
Texture(MaterialTextureBinding),
PropertyGroup(MaterialPropertyGroup),
}Expand description
A value of a resource binding that will be used for rendering.
Limitations
There is a limited set of possible types that can be passed to a shader, most of them are just simple data types.
Variants
Texture(MaterialTextureBinding)
A texture.
PropertyGroup(MaterialPropertyGroup)
A group of properties.
Implementations
Sourceimpl MaterialResourceBinding
impl MaterialResourceBinding
pub const TEXTURE_F_0: &'static str = "Texture@0"
pub const PROPERTY_GROUP_F_0: &'static str = "PropertyGroup@0"
Sourceimpl MaterialResourceBinding
impl MaterialResourceBinding
Sourcepub fn as_texture(&self) -> Option<TextureResource>
pub fn as_texture(&self) -> Option<TextureResource>
Tries to extract a texture from the resource binding.