pub struct Shader {
pub definition: ShaderDefinition,
pub cache_index: Arc<AtomicIndex>,
}Expand description
Internal state of the shader.
Notes
Usually you don’t need to access internals of the shader, but there sometimes could be a need to read shader definition, to get supported passes and properties.
Fields
definition: ShaderDefinitionShader definition contains description of properties and render passes.
cache_index: Arc<AtomicIndex>An id that can be used to create associated GPU resources.
Implementations
Sourceimpl Shader
impl Shader
Sourcepub async fn from_file<P: AsRef<Path>>(
path: P,
io: &dyn ResourceIo,
) -> Result<Self, ShaderError>
pub async fn from_file<P: AsRef<Path>>( path: P, io: &dyn ResourceIo, ) -> Result<Self, ShaderError>
Creates a shader from file.
Sourcepub fn from_string(str: &str) -> Result<Self, ShaderError>
pub fn from_string(str: &str) -> Result<Self, ShaderError>
Creates a shader from string.
Sourcepub fn from_string_bytes(bytes: &[u8]) -> Result<Self, ShaderError>
pub fn from_string_bytes(bytes: &[u8]) -> Result<Self, ShaderError>
Creates a shader from string represented as raw bytes. This function will fail if the bytes
does not contain Utf8-encoded string.
Sourcepub fn find_texture_resource(
&self,
name: &str,
) -> Option<&ShaderResourceDefinition>
pub fn find_texture_resource( &self, name: &str, ) -> Option<&ShaderResourceDefinition>
Tries to find a texture resource with the specified name.
Sourcepub fn find_property_group_resource(
&self,
name: &str,
) -> Option<&ShaderResourceDefinition>
pub fn find_property_group_resource( &self, name: &str, ) -> Option<&ShaderResourceDefinition>
Tries to find a property group resource with the specified name.
Sourcepub fn has_texture_resource(&self, name: &str) -> bool
pub fn has_texture_resource(&self, name: &str) -> bool
Checks if this shader has a texture resource with the specified name.
Sourcepub fn has_property_group_resource(&self, name: &str) -> bool
pub fn has_property_group_resource(&self, name: &str) -> bool
Checks if this shader has a property group resource with the specified name.