pub struct STANDARD { /* private fields */ }Expand description
Standard PBR material. Keep in mind that this material is global, any modification of it will reflect on every other usage of it.
Methods from Deref<Target = BuiltInResource<Material>>